@@ -1,6 +1,6 @@
 DAGbinarytablescore<-function(j,parentnodes,n,param,parenttable,tablemaps,numparents,numberofparentsvec){
-
-    lp<-length(parentnodes) # number of parents
+  
+  lp<-length(parentnodes) # number of parents
   noparams<-2^lp # number of binary states of the parents
   
   corescores<-rep(NA,noparams)
@@ -26,7 +26,7 @@ DAGbinarytablescore<-function(j,parentnodes,n,param,parenttable,tablemaps,numpar
     
     N1s<-collectC(summys,param$d1[,j],noparams)
     N0s<-collectC(summys,param$d0[,j],noparams)
-
+    
     N1slist[[noparams]]<-N1s
     N0slist[[noparams]]<-N0s
     
@@ -34,6 +34,10 @@ DAGbinarytablescore<-function(j,parentnodes,n,param,parenttable,tablemaps,numpar
     
     corescores[noparams] <- scoreconstvec[lp+1] + sum(lgamma(N0s+chi/(2*noparams))) + sum(lgamma(N1s+chi/(2*noparams))) - sum(lgamma(NTs+chi/noparams))
     
+    if (!is.null(param$logedgepmat)) { # if there is an additional edge penalisation
+      corescores[noparams] <- corescores[noparams] - sum(param$logedgepmat[parentnodes, j])
+    }
+    
     for (jj in (noparams-1):1){ # use poset to combine sets
       
       lplocal<-numberofparentsvec[jj] # size of parent set
@@ -42,7 +46,7 @@ DAGbinarytablescore<-function(j,parentnodes,n,param,parenttable,tablemaps,numpar
       missingparentindex<-parenttable[tablemaps$backwards[noparams-tablemaps$forward[jj]+1],1] # get first element of complement of parent set
       higherlayer<-tablemaps$backwards[tablemaps$forward[jj]+2^(missingparentindex-1)] # get row of poset element with this missing parent included
       missingparent<-which(parenttable[higherlayer,]==missingparentindex) # which component it is in the higher layer
-     
+      
       
       N1stemp<-N1slist[[higherlayer]] # map to the previous lists with missing parent added
       N0stemp<-N0slist[[higherlayer]] 
@@ -68,10 +72,10 @@ DAGbinarytablescore<-function(j,parentnodes,n,param,parenttable,tablemaps,numpar
       
       if (!is.null(param$logedgepmat)) { # if there is an additional edge penalisation
         if(lplocal>0) {
-        localparents <- parentnodes[parenttable[jj, 1:lplocal]]
-        if(length(localparents)>0) {
-          corescores[jj] <- corescores[jj] - sum(param$logedgepmat[localparents, j])
-        }
+          localparents <- parentnodes[parenttable[jj, 1:lplocal]]
+          if(length(localparents)>0) {
+            corescores[jj] <- corescores[jj] - sum(param$logedgepmat[localparents, j])
+          }
         }
       }
     }
@@ -107,7 +111,7 @@ DAGbinarytablescoreplus1<-function(j,parentnodes,additionalparent,n,param,parent
   
   N1s<-collectC(summys,param$d1[,j],noparamsadd)
   N0s<-collectC(summys,param$d0[,j],noparamsadd)
-
+  
   N1slist[[noparams]]<-N1s
   N0slist[[noparams]]<-N0s
   
@@ -116,9 +120,9 @@ DAGbinarytablescoreplus1<-function(j,parentnodes,additionalparent,n,param,parent
   corescores[noparams] <- scoreconstvec[lpadd+1] + sum(lgamma(N0s+chi/(2*noparamsadd))) + sum(lgamma(N1s+chi/(2*noparamsadd))) - sum(lgamma(NTs+chi/noparamsadd))
   
   if (!is.null(param$logedgepmat)) { # if there is an additional edge penalisation
-    corescores[noparams] <- corescores[noparams] - param$logedgepmat[additionalparent, j]
+    corescores[noparams] <- corescores[noparams] - sum(param$logedgepmat[allparents, j])
   }
-
+  
   if(lpadd>1){ # otherwise there are no further terms to compute!  
     
     for (jj in (noparams-1):1){ # use poset to combine sets
@@ -155,7 +159,7 @@ DAGbinarytablescoreplus1<-function(j,parentnodes,additionalparent,n,param,parent
         if (lplocal>1) {
           localparents <- c(parentnodes[parenttable[jj, 1:(lplocal-1)]], additionalparent)
         } else {
-            localparents<-additionalparent
+          localparents<-additionalparent
         }
         corescores[jj] <- corescores[jj] - sum(param$logedgepmat[localparents, j])
       }
